<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Londa puloguramu</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Puloguramu eziri ku sisitemu</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Wandika ekiragiriro kyo</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Kiragiro:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="78"/>
        <source>Application name:</source>
        <translation>Puloguramu:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Obubonero buno bulin&apos;amakulu ga njawlo mu kiwandikiro:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: We kaba waddawo erinnya lya fayiro emu&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: We kaba wadawo mannya ga fayiro ezisukka mu emu&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: We kaba waddawo ndagiriro ey&apos;oku yintaneti emu&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: We kaba waddawo ndagiriro ez&apos;oku yintaneti ezisukkamu emu&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Ekiragiro bwe kimala omulimu gwakyo ekiwandikiro kisigalewo</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="88"/>
        <source>Execute in terminal emulator</source>
        <translation>Omulimu gukolere okuva mu kiwandikiro</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Puloguramu erondedwa y,eba ekola ku fayiro ez&apos;ekika kino bulijjo</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Kola ku bukwatakifo</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="49"/>
        <source>Name</source>
        <translation>Linnya lya kakwatakifo</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="54"/>
        <source>Location</source>
        <translation>Gye kaggukira</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="64"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Yongerako akakwatakifo</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="74"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Gyawo akakwatakifo</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="20"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Okukyusa ekifo ky&apos;akakwatakifo mu lukalala luno kawalulebuwaluzi</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Tandika puloguramu eno</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="42"/>
        <source>&amp;Open</source>
        <translation>&amp;Bikkula</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="55"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Tandika</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="65"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Omulimu gukolere okuva mu ki&amp;wandikiro</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="88"/>
        <source>Cancel</source>
        <translation>Sazzamu</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="102"/>
        <source>Remember for next files of this kind</source>
        <translation>Kino kibeere ku fayiro ez&apos;ekika kino bulijjo</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Kkubo:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Linnya lya fayiro:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="85"/>
        <source>File type:</source>
        <translation>Kika kya fayiro:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="42"/>
        <source>Destination:</source>
        <translation>Ekigenderwa:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="65"/>
        <source>Processing:</source>
        <translation>Omulimu gubindabinda:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="78"/>
        <source>Preparing...</source>
        <translation>Ntegeka...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="85"/>
        <source>Progress:</source>
        <translation>We gutuuse:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="119"/>
        <source>Time remaining:</source>
        <translation>Ebulayo:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="99"/>
        <source>Files processed:</source>
        <translation>Fayiro ezaakakolebwako:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Ebikwata ku fayiro</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Ebitalibimu</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Obusangiro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="132"/>
        <source>File type:</source>
        <translation>Kika kya fayiro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="155"/>
        <source>MIME type:</source>
        <translation>Ekikongojjesedwa MIME:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="195"/>
        <source>File size:</source>
        <translation>Obunene bwa fayiro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="218"/>
        <source>On-disk size:</source>
        <translation>Ekifo ekitwalibwa ku disiki:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="241"/>
        <source>Last modified:</source>
        <translation>Lwe yasemba okukyusibwamu:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>Link target:</source>
        <translation>Enyunzi kw&apos;egguka:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="178"/>
        <source>Open With:</source>
        <translation>Bikkuza:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Lwe yasemba okubikkulwa:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Lwe yakolebwawo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Lirimu:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Kabonero:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Londa akabonero</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Gyawo akabonero</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="397"/>
        <source>Device Usage:</source>
        <translation>Enkozesa y&apos;ekitereka data:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Ndukusa</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Obwanannyini</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="473"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Guluupu:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="457"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Nyini yo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Enteekateeka ya Ndukusa</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Balala:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Fayiro efuuke puloguramu</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Laba ebirimu</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Kyusamu ebirimu</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Tandika mulimu</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>Sticky</source>
        <translation>Olukusa olw&apos;obwanannyini</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetUID</source>
        <translation>Olukusa olwazika UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="763"/>
        <source>SetGID</source>
        <translation>Olukusa olwazika GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Ebyetaagisa obumanyirivu</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Wekyusize</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Londa puloguramu enaakozesebwanga okubikkula fayiro ez&apos;ekika kya &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Tterekero</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Fayiro enjereere</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Etterekero &apos;%1&apos; erondedwa tekkirizibwa</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Ntegeka...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Temuli materekero&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>Bikkulira mu Kat&amp;imbe Kapya</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Bikkulira mu ddirisa &amp;ppya</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Bikkulira mu kiwandiki&amp;ro</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Teeka wano koppi</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Leeta wano</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Kolera wano ennyunzi</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Sazzamu</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Tekisoboka okuteera wano</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Kolawo akakwatakifo akapya</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Fayiro &apos;%1&apos; erabika nyunzi ey&apos;ekika kya &apos;freedesktop&apos;.
Kiki ekiba kikolebwa wano?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Fayiro ey&apos;ebigambo &apos;%1&apos; eringa erimu ebiragiro bya kompyuta.
Kiki ekiba kikolebwa wano?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Fayiro &apos;%1&apos; esobola okukola nga puloguramu. Oyagala okugitandika?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="115"/>
        <source>Go Back</source>
        <translation>Ddayo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Kkono</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="122"/>
        <source>Go Forward</source>
        <translation>Weyongereyo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="123"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Ddyo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="130"/>
        <source>Reload</source>
        <translation>Ddamu okubikkula</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="131"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Create Folder</source>
        <translation>Kolawo tterekero</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Icon View</source>
        <translation>Fayiro zirage ng&apos;obufaananyi obuyunzi</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Thumbnail View</source>
        <translation>Fayiro zirage n&apos;akalozako kazo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Compact View</source>
        <translation>Fayiro ziragire mu bimpi</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Detailed List View</source>
        <translation>Laga ebifa ku fayiro mu bujjuvu</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Icon Sizes</source>
        <translation>Bunene bw&apos;obufaanayi</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="186"/>
        <source>Size of big icons:</source>
        <translation>Ebipimo by&apos;obufaananyi obuyunzi obunene:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="193"/>
        <source>Size of small icons:</source>
        <translation>Ebipimo by&apos;obufaananyi obuyunzi obutono:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Size of thumbnails:</source>
        <translation>Ebipimo eby&apos;obulozako bwa fayiro:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="216"/>
        <source>Show Hidden</source>
        <translation>Laga fayiro enkise</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="228"/>
        <source>Show Thumbnails</source>
        <translation>Ndaganga obulozako bwa fayiro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="233"/>
        <source>Show File Tooltips</source>
        <translation>Mpanga magezi ku bya fayiro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="240"/>
        <source>Smooth Scrolling</source>
        <translation>Ebiseesebwa ku lutimbe biseeyeeyebuseeyezi</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="255"/>
        <source>Options</source>
        <translation>Ebisoboka</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <location filename="../filedialog.cpp" line="1064"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <source>Please select a file</source>
        <translation>Londa fayiro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="681"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 gyeri.
Oyagala okuzza ebirala mu kifo kya yo?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1026"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Tewali kkubo &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1040"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; ssi tterekero</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1050"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; ssi fayiro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1204"/>
        <location filename="../filedialog.cpp" line="1321"/>
        <source>&amp;Open</source>
        <translation>&amp;Bikkula</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1207"/>
        <location filename="../filedialog.cpp" line="1329"/>
        <source>&amp;Save</source>
        <translation>&amp;Kazza</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1214"/>
        <source>All Files (*)</source>
        <translation>Laga ebika bya fayiro byonna (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Open File</source>
        <translation>Bikkula fayiro</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="141"/>
        <source>Save File</source>
        <translation>Kazza fayiro</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Bikkula</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Bikkuza...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Many files</source>
        <translation>Fayiro ezisukka mu emu</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="420"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Oyagala okubikkula eno fayiro %1?</numerusform>
            <numerusform>Oyagala okubikkula fayiro zino %1?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="181"/>
        <source>Other Applications</source>
        <translation>Puloguramu ndala</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="188"/>
        <source>Create &amp;New</source>
        <translation>&amp;Kolawo ekipya</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="207"/>
        <source>&amp;Restore</source>
        <translation>&amp;Zawo</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="217"/>
        <source>Cut</source>
        <translation>Situlawo</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="221"/>
        <source>Copy</source>
        <translation>Koppa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="225"/>
        <source>Paste</source>
        <translation>Paatiika</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="229"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Twala mu bisuulidwa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Rename</source>
        <translation>Kyusa erinnya</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="289"/>
        <source>Mount</source>
        <translation>Wanga</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="303"/>
        <source>Unmount</source>
        <translation>Wangula</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="317"/>
        <source>Eject</source>
        <translation>Wandula</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="338"/>
        <source>Extract to...</source>
        <translation>Pakulira...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="346"/>
        <source>Extract Here</source>
        <translation>Pakulira wano</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Compress</source>
        <translation>Pakira</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="362"/>
        <source>Properties</source>
        <translation>Ebikwata ku fayiro</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="376"/>
        <source>Trust selected executables</source>
        <translation>Puloguramu ezirondedwa zeesigibwa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="377"/>
        <source>Trust this executable</source>
        <translation>Puloguramu eno yeesgibwa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="482"/>
        <source>Output</source>
        <translation>Ebivaamu</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="211"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Delete</source>
        <translation>&amp;Gyawo</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Tekisobose fayiro ezimu okuzitwala mu bisuulidwa kubanga sisitemu eza fayiro kwe ziri tezikolagana n&apos;ekifo ekyo.
Fayiro ezo zo nzigyeewobugyi?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Kakasa</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Fayiro gy&apos;olonze ngigyewo?</numerusform>
            <numerusform>Fayiro z&apos;olonze nzigyewo?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Fayiro gy&apos;olonze ngitwale mu bisuulidwa?</numerusform>
            <numerusform>Fayiro z&apos;olonze nzitwale mu bisuulidwa?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move Files</source>
        <translation>Simbuliza fayiro</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Fayiro zino nzijjulula zigende mu tterekero ddala:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Fayiro zikolemu koppi</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Fayiro zino nzikolamu koppi ezinaasangibwa mu tterekero ddala:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Twala fayiro mu bisuulidwa</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Fayiro zino nzitwala mu bisuulidwa:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Gyawo fayiro</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Nzigyawo fayiro zino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Kolawo enyunzi</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Fayiro zino nzikolera nyunzi:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Kyusa atiributo</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Nkyusa atiributo ez&apos;oku fayiro zino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Komyawo fayiro okuva mu bisuulidwa</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Fayiro zino nzikomyawo okuva mu bisuulidwa:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>View folder content</source>
        <translation>Okulaba ebiri mu tterekero</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>View and modify folder content</source>
        <translation>Okulaba n&apos;okukyusa ebiri mu tterekero</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="172"/>
        <source>Read</source>
        <translation>Okubikkula</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="173"/>
        <source>Read and write</source>
        <translation>Okubikkula n&apos;okukyusa</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="175"/>
        <source>Forbidden</source>
        <translation>Tewali kikkirizibwa</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="292"/>
        <source>Files of different types</source>
        <translation>Fayiro zaawukana bika</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="315"/>
        <location filename="../filepropsdialog.cpp" line="322"/>
        <location filename="../filepropsdialog.cpp" line="329"/>
        <source>N/A</source>
        <translation>Tekijjirawo</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="333"/>
        <source>Multiple Files</source>
        <translation>Fayiro ezisukka mu emu</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="410"/>
        <source>%p% used</source>
        <translation>Kukozesedwako %p%</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="411"/>
        <source>%1 Free of %2</source>
        <translation>Kusigaddeko %1 ku %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="457"/>
        <source>no file</source>
        <translation>bbanga</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="459"/>
        <source>one file</source>
        <translation>fayiro emu</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="461"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>fayiro %Ln</numerusform>
            <numerusform>fayiro %Ln</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="495"/>
        <location filename="../filepropsdialog.cpp" line="540"/>
        <source>Select an icon</source>
        <translation>Londa akafaananyi akayunzi</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="497"/>
        <location filename="../filepropsdialog.cpp" line="542"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Bifaananyi (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="648"/>
        <source>Apply changes</source>
        <translation>Kazza ebikyusidwa</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="649"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Enkyuka zino nzikole ku fayiro zonna n&apos;amaterekero agali munda mu lino?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>You should add at least one directory to search.</source>
        <translation>Kyetaagisa okuteekamu etterekero wakiri limu erinaanoonyezebwamu.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="164"/>
        <source>Select a folder</source>
        <translation>Londa tterekero</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="492"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Koppi y&apos;etterekero tesobola okugenda mu tterekero eryo!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="543"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Sisobola okukolera nyunzi mu kifo ekitegekedwa mu nkola etakwatagana ne sisitemu eno</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Empty Trash</source>
        <translation>Kunkumula ebisuulidwa</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="70"/>
        <source>Create &amp;New</source>
        <translation>Kolawo &amp;ekipya</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="75"/>
        <source>&amp;Paste</source>
        <translation>&amp;Paatiika</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="89"/>
        <source>Select &amp;All</source>
        <translation>Londa byo&amp;nna</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="100"/>
        <source>Sorting</source>
        <translation>Sengeka fayiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="105"/>
        <source>Show Hidden</source>
        <translation>Laga fayiro enkise</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="140"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Ebik&amp;wata ku tterekero</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="183"/>
        <source>Output</source>
        <translation>Ebivaamu</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By File Name</source>
        <translation>Sengekera ku mannya ga fayiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="206"/>
        <source>By Modification Time</source>
        <translation>Sengekera ku makyusa</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="207"/>
        <source>By Creation Time</source>
        <translation>Sengekera ku fayiro lwe zaakolebwawo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="210"/>
        <source>By Deletion Time</source>
        <translation>Sengekera ku fayiro lwe zaagyibwawo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Size</source>
        <translation>Sengekera ku bunene</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Type</source>
        <translation>Sengekera ku kika kya fayiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="215"/>
        <source>By File Owner</source>
        <translation>Sengekera ku mannya ga bannyini fayiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="216"/>
        <source>By File Group</source>
        <translation>Sengekera ku mannya ga guluupu</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="222"/>
        <source>Ascending</source>
        <translation>Tandikira awasooka</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="227"/>
        <source>Descending</source>
        <translation>Tandikira awasemba</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="244"/>
        <source>Folder First</source>
        <translation>Soosa materekero</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="252"/>
        <source>Hidden Last</source>
        <translation>Sembyayo ebikisibwa</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="260"/>
        <source>Case Sensitive</source>
        <translation>Yawula mu nnukuta nnene n&apos;entono</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>Location:</source>
        <translation>Busangiro:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File type:</source>
        <translation>Kika kya fayiro:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>File size:</source>
        <translation>Bunene bwa fayiro:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Last modified:</source>
        <translation>Amakyuka agaasemba:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last accessed:</source>
        <translation>Amabikkula agaasemba:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>N/A</source>
        <translation>Tekijjirawo</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="323"/>
        <source>Created:</source>
        <translation>Lweyakolebwawo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="328"/>
        <source>Owner:</source>
        <translation>Nyini yo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Group:</source>
        <translation>Guluupu:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Name</source>
        <translation>Linnya</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Type</source>
        <translation>Kika</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Size</source>
        <translation>Bunene</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="405"/>
        <source>Modified</source>
        <translation>Amakyusa</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="408"/>
        <source>Created</source>
        <translation>Lweyakolebwa</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="411"/>
        <source>Deleted</source>
        <translation>Lweyagibwawo</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="414"/>
        <source>Owner</source>
        <translation>Nyini yo</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="417"/>
        <source>Group</source>
        <translation>Guluupu</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="410"/>
        <source>Auto-resize columns</source>
        <translation>Enkumbo zeekyusize obugazi</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="427"/>
        <source>Visible Columns</source>
        <translation>Enkumbo eziribaka</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Ennukuta enziggumivu</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Ennukuta ensurifu</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
        <source>&amp;Connect</source>
        <translation>&amp;Kwatagana</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="123"/>
        <source>&amp;Edit Path</source>
        <translation>Ky&amp;usa kkubo</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="126"/>
        <source>&amp;Copy Path</source>
        <translation>K&amp;wata kkubo</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Bifo</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Awakolerwa</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Kompyuta</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Puloguramu</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Kayungirizi</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Byuma</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Bukwatakifo</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Bisuulidwa</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="563"/>
        <source>Open in New Tab</source>
        <translation>Bikkulira mu katimbe kapya</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="567"/>
        <source>Open in New Window</source>
        <translation>Bikkulira mu ddirisa ppya</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="580"/>
        <source>Empty Trash</source>
        <translation>Kunkumula bisuulidwa</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="600"/>
        <location filename="../placesview.cpp" line="667"/>
        <source>Hide</source>
        <translation>Kisa</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="617"/>
        <source>Move Bookmark Up</source>
        <translation>Akakwatakifo k&apos;ambuse</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="624"/>
        <source>Move Bookmark Down</source>
        <translation>Akakwatakifo kasse</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="629"/>
        <source>Rename Bookmark</source>
        <translation>Kyusa linnya lya kakwatakifo</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="633"/>
        <source>Remove Bookmark</source>
        <translation>Gyawo kakwatakifo</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="643"/>
        <location filename="../placesview.cpp" line="681"/>
        <source>Unmount</source>
        <translation>Wangula</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="647"/>
        <source>Mount</source>
        <translation>Wanga</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="653"/>
        <source>Eject</source>
        <translation>Wandula</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="658"/>
        <source>Safely Remove</source>
        <translation>Wandula Ekitereka Data Ekigyikamu</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="693"/>
        <source>Show All Entries</source>
        <translation>Laga ebirimu byonna</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Kika: %1
Bunene: %2
Amakyusa: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Kika: %1
Amakyusa: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="104"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Gyawo esangidwawo</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="106"/>
        <source>&amp;Rename</source>
        <translation>Ky&amp;usa erinnya</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="116"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Fayiro tesobola okwewandikako.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Kyetaagisa olonde erinnya ddala.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Lists</source>
        <translation>Nkalala</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Ngobereragana y&apos;amaterekero</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Sisobodde okukomyawo fayiro &apos;%s&apos;: ekkubo eryagituukangako limbuze</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Wanga</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Kwatagana nga a&amp;teyanjudde</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Kwataganisa &amp;linnya lya mukozesa lino:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="76"/>
        <source>&amp;Username:</source>
        <translation>&amp;Erinnya lya mukozesa:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="108"/>
        <source>&amp;Password:</source>
        <translation>Ka&amp;sumuluzo:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="89"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domeyini:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>&amp;Tokwata kasumuluzo</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Session length is determined by password manager</source>
        <translation>Puloguramu eteekateeka busumuluzo y&apos;etegeka obuwanvu bw&apos;olukebera</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="140"/>
        <source>Remember password for &amp;this session</source>
        <translation>K&amp;wata akasumuluzo akakozesedwa okutandika olutuula luno</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="150"/>
        <source>Remember &amp;forever</source>
        <translation>Akasumuluzo kabeere ka lu&amp;beerera</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>Rename File</source>
        <translation>Kyusa erinnya lya fayiro</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="171"/>
        <source>Please enter a new name:</source>
        <translation>Wandika erinnya ppya:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="674"/>
        <location filename="../mountoperation.cpp" line="315"/>
        <location filename="../utilities.cpp" line="154"/>
        <location filename="../utilities.cpp" line="318"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="230"/>
        <source>Create Folder</source>
        <translation>Kolawo tterekero</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Create File</source>
        <translation>Kolawo fayiro</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="235"/>
        <source>Please enter a new file name:</source>
        <translation>Wandika erinnya lya fayiro ppya:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>New file</source>
        <translation>Kolawo fayiro mpya</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="240"/>
        <source>Please enter a new folder name:</source>
        <translation>Wandika erinnya lya tterekero ppya:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="241"/>
        <source>New folder</source>
        <translation>Kolawo tterekero ppya</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="246"/>
        <source>Enter a name for the new %1:</source>
        <translation>Wandika erinnya lya %1 empya:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="692"/>
        <source>Custom Icon Error</source>
        <translation>Wazzewo kiremya ku kafaananyi akayunzi</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Ekifo ekkubo mwerigguka tekiwangidwa ku sisitemu.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Fayiro tebalibwa nga enyunzi ey&apos;ekika kya &apos;freedesktop&apos;: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>&apos;%1&apos; tetegekedwa puloguramu ey&apos;enkalakalira egikolako</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Nnemedwa okukyusa etterekero erikolebwamu libe &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Obumanye: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>Tekijjirawo</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Kakasa nti fayiro ezisangidwawo za kugyibwawo</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wasangidwawo fayiro endala nga erinnya lye lirimu.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Fayiro eyo oyagala esooke egyibwewo?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="76"/>
        <source>with the following file?</source>
        <translation>waddewo fayiro eno?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>E&amp;rinnya lya fayiro:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Ekirondedwa kitegekebwe ne ku fayiro endala zonna eziriwo</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Noonya fayiro</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Erinnya/Busangiro</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Ebiteekwa okusangibwa mu mannya ga fayiro:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Kozesa emboozi enoonya zinnewaayo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Ebifo eby&apos;okunoonyezamu:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Yongerako</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>&amp;Gyawo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Noonya fayiro nkise</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Kika kya fayiro</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Noonya fayiro za bika bino byokka:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Fayiro ez&apos;ebigambo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Fayiro ez&apos;ebifaananyi</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Fayiro ez&apos;ebiwulirizibwa</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Fayiro eza vidiyo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Ebiwandike</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Materekero</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Ebisangibwa mu fayiro</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Fayiro erimu bino:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Kozesa emboozi enoonya zinnewaayo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Ebikwata ku fayiro</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Bunene bwa fayiro:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Larger than:</source>
        <translation>Ezisukka mu:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>Bayiti</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="307"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="312"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="317"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="325"/>
        <source>Smaller than:</source>
        <translation>Ezitasukka mu:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Yawula mu nnukuta nnene n&apos;entono</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Noonyeza ne mu materekero agasangibwa mu gannaago</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>&amp;Yawula mu nnukuta nnene n&apos;entono</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Amakyusa agaasemba:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Mu biseera ebikulembera:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="402"/>
        <source>Later than:</source>
        <translation>Oluvannyuma lwa:</translation>
    </message>
</context>
</TS>
